[SCM] WebKit Debian packaging branch, webkit-1.1, updated. upstream/1.1.19-706-ge5415e9

abarth at webkit.org abarth at webkit.org
Thu Feb 4 21:21:33 UTC 2010


The following commit has been merged in the webkit-1.1 branch:
commit 557ef828903c35cf4178997d9ea709d5db8b7b57
Author: abarth at webkit.org <abarth at webkit.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Wed Jan 20 11:28:04 2010 +0000

    2010-01-20  Adam Barth  <abarth at webkit.org>
    
            Reviewed by Eric Seidel.
    
            Teach check-webkit-style about WebKit/gtk/tests
            https://bugs.webkit.org/show_bug.cgi?id=33892
    
            Removes false positives found in
            https://bugs.webkit.org/show_bug.cgi?id=30883
    
            * Scripts/webkitpy/style/cpp_style.py:
            * Scripts/webkitpy/style/cpp_style_unittest.py:
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@53539 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKitTools/ChangeLog b/WebKitTools/ChangeLog
index 71d0b68..b47de36 100644
--- a/WebKitTools/ChangeLog
+++ b/WebKitTools/ChangeLog
@@ -2,6 +2,19 @@
 
         Reviewed by Eric Seidel.
 
+        Teach check-webkit-style about WebKit/gtk/tests
+        https://bugs.webkit.org/show_bug.cgi?id=33892
+
+        Removes false positives found in
+        https://bugs.webkit.org/show_bug.cgi?id=30883
+
+        * Scripts/webkitpy/style/cpp_style.py:
+        * Scripts/webkitpy/style/cpp_style_unittest.py:
+
+2010-01-20  Adam Barth  <abarth at webkit.org>
+
+        Reviewed by Eric Seidel.
+
         Teach check-webkit-style about QGVLauncher
         https://bugs.webkit.org/show_bug.cgi?id=33890
 
diff --git a/WebKitTools/Scripts/webkitpy/style/cpp_style_unittest.py b/WebKitTools/Scripts/webkitpy/style/cpp_style_unittest.py
index 1096db1..54a961d 100644
--- a/WebKitTools/Scripts/webkitpy/style/cpp_style_unittest.py
+++ b/WebKitTools/Scripts/webkitpy/style/cpp_style_unittest.py
@@ -3631,6 +3631,7 @@ class WebKitStyleTest(CppStyleTestBase):
         self.assert_(cpp_style.is_exempt('WebKit/qt/Api/qwebpage.h'))
         self.assert_(cpp_style.is_exempt('JavaScriptCore/qt/api/qscriptengine_p.h'))
         self.assert_(cpp_style.is_exempt('WebKit/qt/tests/qwebsecurityorigin/tst_qwebsecurityorigin.cpp'))
+        self.assert_(cpp_style.is_exempt('WebKit/gtk/tests/testatk.c'))
 
 def tearDown():
     """A global check to make sure all error-categories have been tested.

diff --git a/WebKitTools/Scripts/webkitpy/style/cpp_style.py b/WebKitTools/Scripts/webkitpy/style/cpp_style.py
index c752af3..d54d9e0 100644
--- a/WebKitTools/Scripts/webkitpy/style/cpp_style.py
+++ b/WebKitTools/Scripts/webkitpy/style/cpp_style.py
@@ -2936,9 +2936,9 @@ def is_exempt(filename):
      """
     if (filename.find('WebKit/qt/Api/') >= 0
         or filename.find('JavaScriptCore/qt/api/') >= 0
-        or filename.find('WebKit/qt/tests/') >= 0):
-        # The Qt API and tests do not follow WebKit style.
-        # They follow Qt style. :)
+        or filename.find('WebKit/qt/tests/') >= 0
+        or filename.find('WebKit/gtk/tests/') >= 0):
+        # The Qt API and the Qt and Gtk tests do not follow WebKit style.
         return True
 
     return os.path.basename(filename) in (
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list